pub struct AssetIdParams {
pub id: String,
}Fields
id: StringTrait Implementations
Sourceimpl Debug for AssetIdParams
impl Debug for AssetIdParams
Sourceimpl<'de> Deserialize<'de> for AssetIdParams
impl<'de> Deserialize<'de> for AssetIdParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AssetIdParams
impl JsonSchema for AssetIdParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AssetIdParams
impl RefUnwindSafe for AssetIdParams
impl Send for AssetIdParams
impl Sync for AssetIdParams
impl Unpin for AssetIdParams
impl UnsafeUnpin for AssetIdParams
impl UnwindSafe for AssetIdParams