pub struct AssetIdsParams {
pub ids: Vec<String>,
}Fields
ids: Vec<String>Trait Implementations
Sourceimpl Debug for AssetIdsParams
impl Debug for AssetIdsParams
Sourceimpl<'de> Deserialize<'de> for AssetIdsParams
impl<'de> Deserialize<'de> for AssetIdsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AssetIdsParams
impl JsonSchema for AssetIdsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AssetIdsParams
impl RefUnwindSafe for AssetIdsParams
impl Send for AssetIdsParams
impl Sync for AssetIdsParams
impl Unpin for AssetIdsParams
impl UnsafeUnpin for AssetIdsParams
impl UnwindSafe for AssetIdsParams