pub struct EmptyMediaParams {}Trait Implementations
Sourceimpl Debug for EmptyMediaParams
impl Debug for EmptyMediaParams
Sourceimpl<'de> Deserialize<'de> for EmptyMediaParams
impl<'de> Deserialize<'de> for EmptyMediaParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmptyMediaParams
impl JsonSchema for EmptyMediaParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EmptyMediaParams
impl RefUnwindSafe for EmptyMediaParams
impl Send for EmptyMediaParams
impl Sync for EmptyMediaParams
impl Unpin for EmptyMediaParams
impl UnsafeUnpin for EmptyMediaParams
impl UnwindSafe for EmptyMediaParams