pub struct ListAssetsParams {
pub filter: AssetFilter,
pub query: String,
pub sort: AssetSort,
pub page: i32,
}Fields
filter: AssetFilterquery: Stringsort: AssetSortpage: i32Trait Implementations
Sourceimpl Debug for ListAssetsParams
impl Debug for ListAssetsParams
Sourceimpl<'de> Deserialize<'de> for ListAssetsParams
impl<'de> Deserialize<'de> for ListAssetsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListAssetsParams
impl JsonSchema for ListAssetsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListAssetsParams
impl RefUnwindSafe for ListAssetsParams
impl Send for ListAssetsParams
impl Sync for ListAssetsParams
impl Unpin for ListAssetsParams
impl UnsafeUnpin for ListAssetsParams
impl UnwindSafe for ListAssetsParams