pub struct ReadNote {
pub note_id: i32,
pub draft: bool,
pub start_line: usize,
pub max_lines: Option<usize>,
}Fields
note_id: i32draft: bool默认读取收录版(普通令牌读取公开版);工作稿要求笔记写入授权。
start_line: usizemax_lines: Option<usize>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ReadNote
impl<'de> Deserialize<'de> for ReadNote
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReadNote
impl JsonSchema for ReadNote
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReadNote
impl RefUnwindSafe for ReadNote
impl Send for ReadNote
impl Sync for ReadNote
impl Unpin for ReadNote
impl UnsafeUnpin for ReadNote
impl UnwindSafe for ReadNote