pub struct ReadNotebook {
pub notebook_id: i32,
pub page: i32,
}Fields
notebook_id: i32page: i32Trait Implementations
Sourceimpl Debug for ReadNotebook
impl Debug for ReadNotebook
Sourceimpl<'de> Deserialize<'de> for ReadNotebook
impl<'de> Deserialize<'de> for ReadNotebook
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReadNotebook
impl JsonSchema for ReadNotebook
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReadNotebook
impl RefUnwindSafe for ReadNotebook
impl Send for ReadNotebook
impl Sync for ReadNotebook
impl Unpin for ReadNotebook
impl UnsafeUnpin for ReadNotebook
impl UnwindSafe for ReadNotebook