pub struct NoteDraft {
pub id: Option<i32>,
pub expected_version: Option<i32>,
pub kind: NoteKind,
pub title: String,
pub content_md: String,
pub tags: Vec<String>,
pub notebook_ids: Vec<i32>,
}Fields
id: Option<i32>expected_version: Option<i32>更新必须携带读到的版本;过期写入被拒绝。
kind: NoteKindtitle: Stringcontent_md: Stringnotebook_ids: Vec<i32>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for NoteDraft
impl<'de> Deserialize<'de> for NoteDraft
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NoteDraft
impl JsonSchema for NoteDraft
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for NoteDraft