pub struct NoteFilter {
pub query: String,
pub kind: Option<NoteKind>,
pub notebook_id: Option<i32>,
pub tag: String,
pub trash: bool,
pub published: Option<bool>,
pub knowledge: Option<bool>,
pub page: i32,
}Fields
query: Stringkind: Option<NoteKind>notebook_id: Option<i32>tag: Stringtrash: boolpublished: Option<bool>仅管理接口应用;公开查询不能借此探测私密状态。
knowledge: Option<bool>page: i32Trait Implementations
Sourceimpl Clone for NoteFilter
impl Clone for NoteFilter
Sourcefn clone(&self) -> NoteFilter
fn clone(&self) -> NoteFilter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NoteFilter
impl Debug for NoteFilter
Sourceimpl Default for NoteFilter
impl Default for NoteFilter
Sourcefn default() -> NoteFilter
fn default() -> NoteFilter
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NoteFilter
impl<'de> Deserialize<'de> for NoteFilter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NoteFilter
impl JsonSchema for NoteFilter
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NoteFilter
impl PartialEq for NoteFilter
Sourceimpl Serialize for NoteFilter
impl Serialize for NoteFilter
impl StructuralPartialEq for NoteFilter